from .equiflow import TableFlows, TableCharacteristics, TableDrifts, FlowDiagram, EquiFlow, EasyFlow, TablePValues

__author__ = "João Matos <jcmatos@mit.edu>"
__version__ = "0.1.7"

__all__ = ['TableFlows', 'TableCharacteristics', 'TableDrifts', 'FlowDiagram', 'EquiFlow', 'EasyFlow', 'TablePValues']